@@ -1,4 +1,6 @@
-import functools
+from functools import wraps
+
+from sanic import Request
 
 from sanic_beskar.exceptions import (
     BeskarError,
@@ -17,7 +19,7 @@ from sanic_beskar.utilities import (
 )
 
 
-async def _verify_and_add_token(request, optional=False):
+async def _verify_and_add_token(request=None, optional=False):
     """
     This helper method just checks and adds token data to the app context.
     If optional is False and the header is missing the token, just returns.
@@ -61,9 +63,13 @@ def auth_required(method):
         MissingToken: No authenticated user token is available to authorize.
     """
 
-    @functools.wraps(method)
+    @wraps(method)
     async def wrapper(request, *args, **kwargs):
-        await _verify_and_add_token(request)
+        # TODO: hack to work around class based views
+        if not isinstance(request, Request):
+            if isinstance(args[0], Request):
+                request = args[0]
+        await _verify_and_add_token(request=request)
         try:
             return await method(request, *args, **kwargs)
         finally:
@@ -84,8 +90,12 @@ def auth_accepted(method):
     Returns:
         NoReturn: Decorator
     """
-    @functools.wraps(method)
+    @wraps(method)
     async def wrapper(request, *args, **kwargs):
+        # TODO: hack to work around class based views
+        if not isinstance(request, Request):
+            if isinstance(args[0], Request):
+                request = args[0]
         try:
             await _verify_and_add_token(request, optional=True)
             return await method(request, *args, **kwargs)
@@ -115,12 +125,16 @@ def roles_required(*required_rolenames):
     """
 
     def decorator(method):
-        @functools.wraps(method)
+        @wraps(method)
         async def wrapper(request, *args, **kwargs):
             BeskarError.require_condition(
                 not current_guard().roles_disabled,
                 "This feature is not available because roles are disabled",
             )
+            # TODO: hack to work around class based views
+            if not isinstance(request, Request):
+                if isinstance(args[0], Request):
+                    request = args[0]
             await _verify_and_add_token(request)
             try:
                 MissingRoleError.require_condition(
@@ -159,12 +173,16 @@ def rights_required(*required_rights):
     """
 
     def decorator(method):
-        @functools.wraps(method)
+        @wraps(method)
         async def wrapper(request, *args, **kwargs):
             BeskarError.require_condition(
                 current_guard().rbac_definitions != {},
                 "This feature is not available because RBAC is not enabled",
             )
+            # TODO: hack to work around class based views
+            if not isinstance(request, Request):
+                if isinstance(args[0], Request):
+                    request = args[0]
             await _verify_and_add_token(request)
             try:
                 current_roles = await current_rolenames()
@@ -206,12 +224,16 @@ def roles_accepted(*accepted_rolenames):
     """
 
     def decorator(method):
-        @functools.wraps(method)
+        @wraps(method)
         async def wrapper(request, *args, **kwargs):
             BeskarError.require_condition(
                 not current_guard().roles_disabled,
                 "This feature is not available because roles are disabled",
             )
+            # TODO: hack to work around class based views
+            if not isinstance(request, Request):
+                if isinstance(args[0], Request):
+                    request = args[0]
             await _verify_and_add_token(request)
             try:
                 MissingRoleError.require_condition(
